dac

package
v0.0.0-...-9eb3501 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2020 License: MPL-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package dac defines the DAC

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DAC

type DAC interface {
	// SetVoltage sets output voltage of a channel.
	SetVoltage(voltage float64, channel int) error

	// SetInputCode sets output voltage using an number that is between
	// and including 0 - (max resolution of DAC - 1).
	SetInputCode(code, channel int) error
}

DAC is the interface to set the output voltage(s) of a Digital Analog Converter.

Jump to