Documentation
¶
Overview ¶
Package dac defines the DAC
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DAC ¶
type DAC interface {
// SetVoltage sets output voltage of a channel.
SetVoltage(voltage float64, channel int) error
// SetInputCode sets output voltage using an number that is between
// and including 0 - (max resolution of DAC - 1).
SetInputCode(code, channel int) error
}
DAC is the interface to set the output voltage(s) of a Digital Analog Converter.
Click to show internal directories.
Click to hide internal directories.